@@ -248,7 +248,7 @@ def calculate_full_name_optimal_font_size(
     separated lines.
 
 
-    @param full_name: A full name.
+    @param full_name: A full name of the person.
 
     @param text_area_width: The width in pixels of the area to display the
         full name.
@@ -256,9 +256,9 @@ def calculate_full_name_optimal_font_size(
     @param font_file_path_name: The absolute path and name of the font
         file to use to display the full name.
 
-    @param first_name: The first name corresponding to the full name.
+    @param first_name: The first name of the person.
 
-    @param last_name: The last name corresponding to the full name.
+    @param last_name: The last name of the person.
 
     @param maximal_font_size: The maximal size of the font to use to
         display the full name.
@@ -270,16 +270,16 @@ def calculate_full_name_optimal_font_size(
     @return: A tuple `(font_size, text_width, text_height, multiline_required)`
         where:
 
-        * `font_size`: The largest font size to display the text in the
+        - `font_size`: The largest font size to display the text in the
           specified area.
 
-        * `text_width`: The width in pixels of the text displayed with this
+        - `text_width`: The width in pixels of the text displayed with this
           font size.
 
-        * `text_height`: The height in pixels of the text displayed with this
+        - `text_height`: The height in pixels of the text displayed with this
           font size.
 
-        * `multiline_required`: `False` if the full name can be displayed on 1
+        - `multiline_required`: `False` if the full name can be displayed on 1
           single line; `True` if the full name MUST be displayed as the first
           name and the last name on 2 separated lines.
     """
@@ -306,10 +306,8 @@ def calculate_full_name_optimal_font_size(
 
     if best_text_width > text_area_width:
         if not first_name or not last_name \
-           or len(first_name) >= len(full_name) or len(last_name) >= len(full_name):
-            print(first_name)
-            print(last_name)
-            print(full_name)
+           or len(first_name) >= len(full_name) \
+           or len(last_name) >= len(full_name):
             raise ValueError("the size of the font is too small compared to the requirement")
 
         best_first_name_font_size, best_first_name_text_width, best_first_name_text_height = \
